v1alpha1

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 6, 2020 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DatadogAgentLister

type DatadogAgentLister interface {
	// List lists all DatadogAgents in the indexer.
	List(selector labels.Selector) (ret []*v1alpha1.DatadogAgent, err error)
	// DatadogAgents returns an object that can list and get DatadogAgents.
	DatadogAgents(namespace string) DatadogAgentNamespaceLister
	DatadogAgentListerExpansion
}

DatadogAgentLister helps list DatadogAgents.

func NewDatadogAgentLister

func NewDatadogAgentLister(indexer cache.Indexer) DatadogAgentLister

NewDatadogAgentLister returns a new DatadogAgentLister.

type DatadogAgentListerExpansion

type DatadogAgentListerExpansion interface{}

DatadogAgentListerExpansion allows custom methods to be added to DatadogAgentLister.

type DatadogAgentNamespaceLister

type DatadogAgentNamespaceLister interface {
	// List lists all DatadogAgents in the indexer for a given namespace.
	List(selector labels.Selector) (ret []*v1alpha1.DatadogAgent, err error)
	// Get retrieves the DatadogAgent from the indexer for a given namespace and name.
	Get(name string) (*v1alpha1.DatadogAgent, error)
	DatadogAgentNamespaceListerExpansion
}

DatadogAgentNamespaceLister helps list and get DatadogAgents.

type DatadogAgentNamespaceListerExpansion

type DatadogAgentNamespaceListerExpansion interface{}

DatadogAgentNamespaceListerExpansion allows custom methods to be added to DatadogAgentNamespaceLister.

Jump to